==> webcamoid_8.5.0+dfsg.orig.tar.xz: webcamoid-8.5.0/libAvKys/Plugins/DesktopCapture/src/desktopcaptureglobals.h <==
/* Webcamoid, webcam capture application.
 * Copyright (C) 2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef DESKTOPCAPTUREGLOBALS_H
#define DESKTOPCAPTUREGLOBALS_H

#include <QObject>

class DesktopCaptureGlobals: public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString captureLib
               READ captureLib
               WRITE setCaptureLib
               RESET resetCaptureLib
               NOTIFY captureLibChanged)

    public:
        DesktopCaptureGlobals(QObject *parent=nullptr);

        Q_INVOKABLE QString captureLib() const;

    private:
        QString m_captureLib;
        QStringList m_preferredLibrary;

    signals:
        void captureLibChanged(const QString &captureLib);

    public slots:
        void setCaptureLib(const QString &captureLib);
        void resetCaptureLib();
};

#endif // DESKTOPCAPTUREGLOBALS_H

==> webcamoid_8.8.0+dfsg.orig.tar.xz: webcamoid-8.8.0/libAvKys/Plugins/DesktopCapture/src/desktopcaptureglobals.h <==
/* Webcamoid, webcam capture application.
 * Copyright (C) 2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef DESKTOPCAPTUREGLOBALS_H
#define DESKTOPCAPTUREGLOBALS_H

#include <QObject>

class DesktopCaptureGlobalsPrivate;

class DesktopCaptureGlobals: public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString captureLib
               READ captureLib
               WRITE setCaptureLib
               RESET resetCaptureLib
               NOTIFY captureLibChanged)
    Q_PROPERTY(QStringList subModules
               READ subModules)

    public:
        DesktopCaptureGlobals(QObject *parent=nullptr);
        ~DesktopCaptureGlobals();

        Q_INVOKABLE QString captureLib() const;
        Q_INVOKABLE QStringList subModules() const;

    private:
        DesktopCaptureGlobalsPrivate *d;

    signals:
        void captureLibChanged(const QString &captureLib);

    public slots:
        void setCaptureLib(const QString &captureLib);
        void resetCaptureLib();
};

#endif // DESKTOPCAPTUREGLOBALS_H
